*********************************************************
* COVID-19, Domestic Violence, and Alcohol Consumption. *
* May 30 2020.                                          *
*********************************************************


* Tabla 1  Descriptive Statistics

 use "Base.dta"
 
 gen After=0
 replace After=1 if periodo>=7 & periodo<=14
 tab After
 
 label variable viot "Domestic Violence Calls (per 100,000 persons)"
 label variable psit  "Psychological Domestic Violence Calls (per 100,000 persons)"
 label variable jurt "Legal Domestic Violence Calls (per 100,000 persons)"
 label variable unionlibre "Cohabiting"
 label variable empleada "Working"
 label variable bachillerato "High School or more"
 
 
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2019 & After==1
 est store A
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2019 & After==0
 est store B
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & After==1
 est store C
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & After==0
 est store D
 
 esttab A B C D   using Table1.tex, replace ///
 mtitle(""  "" "") ///
 cells(mean(fmt(2)))  label nonumber f noobs alignment(S) booktabs

 

 ttest viot if ano==2019, by(After)
 ttest viot if ano==2020, by(After)
 
 ttest psit if ano==2019, by(After)
 ttest psit if ano==2020, by(After)
 
 ttest jurt if ano==2019, by(After)
 ttest jurt if ano==2020, by(After)
 
 ttest unionlibre if ano==2019, by(After)
 ttest unionlibre if ano==2020, by(After)
 
 ttest empleada if ano==2019, by(After)
 ttest empleada if ano==2020, by(After)
 
 ttest bachillerato if ano==2019, by(After)
 ttest bachillerato if ano==2020, by(After)
 
 
 * Tabla 3  Descriptive Statistics (Alcohol)
 
 use "BaseAlcohol.dta"
 
 gen Treatment=0
 replace Treatment=1 if cmunicipio_usuaria==569 
 replace Treatment=1 if cmunicipio_usuaria==293
 replace Treatment=1 if cmunicipio_usuaria==1064 
 replace Treatment=1 if cmunicipio_usuaria==383 
 replace Treatment=1 if cmunicipio_usuaria==288
 replace Treatment=1 if cmunicipio_usuaria==1021
 tab Treatment
 
 gen Afteralc=0
 replace Afteralc=1 if periodo>=10 & periodo<=14
 
 
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & Treatment==1 & Afteralc==0
 est store A
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & Treatment==0 & Afteralc==0
 est store B
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & Treatment==1 & Afteralc==1
 est store C
 estpost su viot psit jurt unionlibre  empleada bachillerato if ano==2020 & Treatment==0 & Afteralc==1
 est store D
 
 esttab A B C D   using Table3.tex, replace ///
 mtitle(""  "" "") ///
 cells(mean(fmt(2)))  label nonumber f noobs alignment(S) booktabs

  
 ttest viot if ano==2020 & Afteralc==0, by(Treatment)
 ttest viot if ano==2020 & Afteralc==1, by(Treatment)
 
 ttest psit if ano==2020 & Afteralc==0, by(Treatment)
 ttest psit if ano==2020 & Afteralc==1, by(Treatment)
 
 ttest jurt if ano==2020 & Afteralc==0, by(Treatment)
 ttest jurt if ano==2020 & Afteralc==1, by(Treatment)
 
 ttest unionlibre if ano==2020 & Afteralc==0, by(Treatment)
 ttest unionlibre if ano==2020 & Afteralc==1, by(Treatment)
 
 ttest empleada if ano==2020 & Afteralc==0, by(Treatment)
 ttest empleada if ano==2020 & Afteralc==1, by(Treatment)
 
 ttest bachillerato if ano==2020 & Afteralc==0, by(Treatment)
 ttest bachillerato if ano==2020 & Afteralc==1, by(Treatment)
  
  
 * Tabla 4  Domestic violence
  
 use "Base.dta"
  
 * 4.1 Preparing the event-study
 
 gen periodimp=.
 replace periodimp=7 if ano==2020 /* Lockdown */
 gen even=periodo-periodimp
 recode even (.=-1)
 tab even 
 
 gen event=even 
 replace event=-6 if even<-6 
 replace event=6 if even>6
 tab event
 
 tab event, gen(T) 
 
 
 * 4.2. Label the weeks
  
  label variable T1 "Week -6"
  label variable T2 "Week -5"
  label variable T3 "Week -4"
  label variable T4 "Week -3"
  label variable T5 "Week -2"
  label variable T6 "Week -1"
  label variable T7 "Week 0"
  label variable T8 "Week 1"
  label variable T9 "Week 2"
  label variable T10 "Week 3"
  label variable T11 "Week 4"
  label variable T12 "Week 5"
  label variable T13 "Week 6"
  
 * 4.3. Regressions 
  
 reg viot T1 T2 T3 T4 T5  T7 T8 T9 T10 T11 T12 T13  i.cmunicipio_usuaria i.periodo i.ano unionlibre  empleada bachillerato, cluster(cmunicipio_usuaria)
 est store A
 reg psit T1 T2 T3 T4 T5  T7 T8 T9 T10 T11 T12 T13 i.cmunicipio_usuaria i.periodo i.ano unionlibre  empleada bachillerato, cluster(cmunicipio_usuaria)
 est store B
 reg jurt T1 T2 T3 T4 T5  T7 T8 T9 T10 T11 T12 T13  i.cmunicipio_usuaria i.periodo i.ano unionlibre empleada bachillerato , cluster(cmunicipio_usuaria)
 est store C
 
  esttab A B C ///
  using  "tabla4.tex", ///
  b(3) se(3) se label star(* 0.1 ** 0.05 *** 0.01) ///
  title(OLS Estimates:   \label{lpmpsycho}) ///
  nomtitles r2(2) obslast 
  
 * 4.4. Figures 2 and 3
  
 * Figure 2
 set more off
 eventdd psit unionlibre  empleada bachillerato  ///
 i.cmunicipio_usuaria i.periodo i.ano, timevar(event) cluster(cmunicipio_usuaria)
 
 
 * Figure 3
 set more off
 eventdd jurt unionlibre  empleada bachillerato  ///
 i.cmunicipio_usuaria i.periodo i.ano, timevar(event) cluster(cmunicipio_usuaria)
 
 
 
 * Table 5 Domestic Violence and Alcohol
 
  use "BaseAlcohol.dta"
  
  * 5.1 Preparing the event-study
  
 gen periodimpa=.
 replace periodimpa=10 if cmunicipio_usuaria==569  /* Milpa Altta */ /*debe haber 8 cambios */
 replace periodimpa=11 if cmunicipio_usuaria==293  /* Cuajimalpa de Morelos */
 replace periodimpa=11 if cmunicipio_usuaria==1064  /* Álvaro Obregón */
 replace periodimpa=12 if cmunicipio_usuaria==383  /* Gustavo A. Madero  */
 replace periodimpa=12 if cmunicipio_usuaria==288  /* Coyoacán  */
 replace periodimpa=12 if cmunicipio_usuaria==1021  /* Xochimilco   */
 gen evena=periodo-periodimpa
 recode evena (.=-1)
 tab evena  

 gen eventa=evena 
 replace eventa=-3 if evena<-3 
 replace eventa=3 if evena>3
 tab eventa
 
 tab eventa, gen(T) 
 
 * 5.2. Label the weeks
 
 
  label variable T1 "Week -3"
  label variable T2 "Week -2"
  label variable T3 "Week -1"
  label variable T4 "Week 0"
  label variable T5 "Week 1"
  label variable T6 "Week 2"
  label variable T7 "Week 3"
 
 * 5.3. Regressions 
 
 reg viot T1 T2  T4 T5 T6  T7    i.cmunicipio_usuaria i.periodo unionlibre  empleada bachillerato, cluster(cmunicipio_usuaria)
 est store A
 reg psit T1 T2  T4 T5 T6  T7    i.cmunicipio_usuaria i.periodo unionlibre  empleada bachillerato, cluster(cmunicipio_usuaria)
 est store B
 reg jurt T1 T2  T4 T5 T6  T7   i.cmunicipio_usuaria i.periodo unionlibre  empleada bachillerato, cluster(cmunicipio_usuaria)
 est store C
 esttab A B C ///
 using  "tabla5.tex", ///
 b(3) se(3) se label star(* 0.1 ** 0.05 *** 0.01) ///
 title(OLS Estimates:  \label{lpmpsycho}) ///
 nomtitles r2(2) obslast 
  

 * 5.4. Figures 4 and 5
  
 * Figure 4
 set more off
 eventdd psit unionlibre  empleada bachillerato  ///
 i.cmunicipio_usuaria i.periodo, timevar(eventa) cluster(cmunicipio_usuaria)
 
 * Figure 5
 set more off
 eventdd jurt unionlibre  empleada bachillerato  ///
 i.cmunicipio_usuaria i.periodo, timevar(eventa) cluster(cmunicipio_usuaria)
 
 
 
